import mysql.connector
import json
import pandas as pd

class MySqlConnection:
    def __init__(self):
        pass
        
    def get_connection(self, host, user, password):
        connection = mysql.connector.connect(
            host=host,
            user=user,
            password=password)
        print('connect successfully!!!')
        return connection

    def get_connection_by_json(self, json_file):
        with open(json_file, 'r') as file:
            auth = json.load(file)
        connection = self.get_connection(auth['host'], auth['user'], auth['password'])
        return connection

    def get_database_names(self, connection, with_default_database = False):
        if with_default_database:
            cursor = connection.cursor()
            cursor.execute('show databases')
            databases = [database[0] for database in cursor.fetchall()]
        else:
            cursor = connection.cursor()
            cursor.execute("SHOW DATABASES WHERE `Database` NOT IN ('information_schema', 'mysql', 'performance_schema', 'sys')")
            databases = [database[0] for database in cursor.fetchall()]
            
        return databases

    def get_table_names(self, connection, database):
        try:
            if type(database) == list:
                table_list = {}
                for db in database:
                    cursor = connection.cursor()
                    cursor.execute(f'use {db}')
                    cursor.execute('show tables')
                    tables = [table[0] for table in cursor.fetchall()]
                    table_list[db] = tables
            return table_list
        except Exception as e:
            return f'connection problem: {e}'
 
    def get_table_df(self, table_dict):
        try:
            table_data = []
            for database, tables in table_dict.items():
                for table in tables:
                    table_data.append([database, table])
            df = pd.DataFrame(table_data, columns=['database_name', 'table_name'])
            return df
        except Exception as e:
            return f'problem: {e}'
        
        


from setuptools import setup, find_packages

setup(
    author='Harish Daga',
    description='A module for mysql to get some basic details of database and tables like table ddl and row cound and space usage.',
    name='mysqlmastermanish',
    packages=find_packages(include=['mysqlmastermanish', 'musqlmastermanish.*']),
    install_requires=[
        'boto3==1.34.154',
        'botocore==1.34.154',
        'certifi==2024.7.4',
        'charset-normalizer==3.3.2',
        'docutils==0.21.2',
        'idna==3.7',
        'importlib_metadata==8.2.0',
        'jaraco.classes==3.4.0',
        'jaraco.context==5.3.0',
        'jaraco.functools==4.0.2',
        'jmespath==1.0.1',
        'keyring==25.3.0',
        'markdown-it-py==3.0.0',
        'mdurl==0.1.2',
        'more-itertools==10.3.0',
        'mysql-connector-python==9.0.0',
        'nh3==0.2.18',
        'numpy==2.0.1',
        'pandas==2.2.2',
        'pkginfo==1.10.0',
        'Pygments==2.18.0',
        'Pyment==0.3.3',
        'python-dateutil==2.9.0.post0',
        'pytz==2024.1',
        'readme_renderer==44.0',
        'requests==2.32.3',
        'requests-toolbelt==1.0.0',
        'rfc3986==2.0.0',
        'rich==13.7.1',
        's3transfer==0.10.2',
        'setuptools==72.1.0',
        'six==1.16.0',
        'twine==5.1.1',
        'tzdata==2024.1',
        'urllib3==2.2.2',
        'zipp==3.19.2'
        ],
    python_requires='>=3.6',
    version='0.0.2'
)